==> ci-hotel_V0.9.11_20101212.zip: ci-hotel_V0.0.11_20101212/system/application/views/my/useredit.php <==
<?php
include(dirname(__FILE__) . '/../header1.php');
include(dirname(__FILE__) . '/../my_header2.php');
?>
<h2>ユーザ情報の変更</h2>

<?php echo form_open('my/useredit/'); ?>

<table class="inp">
<tr>
<th width="200px">メールアドレス :</th>
<td>
<input type="text" name="email" value="<?php echo set_value('email', isset($email) ? $email : ''); ?>" size="40" />
<?php echo form_error('email'); ?>
</td>
</tr>
<tr>
<th>パスワード :</th>
<td>
<input type="password" name="password" value="<?php echo set_value('password', isset($password) ? $password : ''); ?>" size="40" />
<?php echo form_error('password'); ?>
</td>
</tr>
<tr>
<th>氏名 :</th>
<td>
<input type="text" name="name" value="<?php echo set_value('name', isset($name) ? $name : ''); ?>" size="40" />
<?php echo form_error('name'); ?>
</td>
</tr>
<tr>
<th>氏名(かな) :</th>
<td>
<input type="text" name="name_kana" value="<?php echo set_value('name_kana', isset($name_kana) ? $name_kana : ''); ?>" size="40" />
<?php echo form_error('name_kana'); ?>
</td>
</tr>
<tr>
<th>郵便番号 :</th>
<td>
<input type="text" name="postcode" value="<?php echo set_value('postcode', isset($postcode) ? $postcode : ''); ?>" size="10" />
<?php echo form_error('postcode'); ?>
</td>
</tr>
<tr>
<th>都道府県 :</th>
<td>
<?php
$prefecture_options = array(
    '北海道' => '北海道',
    '青森県' => '青森県', '岩手県' => '岩手県', '宮城県' => '宮城県', '秋田県' => '秋田県',
    '山形県' => '山形県', '福島県' => '福島県', '茨城県' => '茨城県', '栃木県' => '栃木県',
    '群馬県' => '群馬県', '埼玉県' => '埼玉県', '千葉県' => '千葉県', '東京都' => '東京都',
    '神奈川県' => '神奈川県', '新潟県' => '新潟県', '富山県' => '富山県', '石川県' => '石川県',
    '福井県' => '福井県', '山梨県' => '山梨県', '長野県' => '長野県', '岐阜県' => '岐阜県',
    '静岡県' => '静岡県', '愛知県' => '愛知県', '三重県' => '三重県', '滋賀県' => '滋賀県',
    '京都府' => '京都府', '大阪府' => '大阪府', '兵庫県' => '兵庫県', '奈良県' => '奈良県',
    '和歌山県' => '和歌山県', '鳥取県' => '鳥取県', '島根県' => '島根県', '岡山県' => '岡山県',
    '広島県' => '広島県', '山口県' => '山口県', '徳島県' => '徳島県', '香川県' => '香川県',
    '愛媛県' => '愛媛県', '高知県' => '高知県', '福岡県' => '福岡県', '佐賀県' => '佐賀県',
    '長崎県' => '長崎県', '熊本県' => '熊本県', '大分県' => '大分県', '宮崎県' => '宮崎県',
    '鹿児島県' => '鹿児島県', '沖縄県', '沖縄県'
);
echo form_dropdown('prefecture', $prefecture_options, set_value('prefecture', isset($prefecture) ? $prefecture : ''));
echo form_error('prefecture');
?>
</td>
</tr>
<tr>
<th>市区町村 :</th>
<td>
<input type="text" name="city" value="<?php echo set_value('city', isset($city) ? $city : ''); ?>" size="40" />
<?php echo form_error('city'); ?>
</td>
</tr>
<tr>
<th>番地 :</th>
<td>
<input type="text" name="street" value="<?php echo set_value('street', isset($street) ? $street : ''); ?>" size="40" />
<?php echo form_error('street'); ?>
</td>
</tr>
<tr>
<th>電話番号 :</th>
<td>
<input type="text" name="phone" value="<?php echo set_value('phone', isset($phone) ? $phone : ''); ?>" size="20" />
<?php echo form_error('phone'); ?>
</td>
</tr>
</table>

<input type="submit" name="submit" value="確認画面に進む" />
</form>

<?php
include(dirname(__FILE__) . '/../footer.php');
?>

==> ci-hotel_V1.0.2_20101221.zip: ci-hotel_V1.0.2_20101221/system/application/views/my/useredit.php <==
<?php
include(dirname(__FILE__) . '/../header1.php');
include(dirname(__FILE__) . '/../my_header2.php');
?>
<h2>会員情報の変更</h2>

<?php
if (isset($error) && count($error))
{
    echo '<div class="form_error"><ul>' . "\n";
    foreach ($error as $err)
    {
        echo "<li>" . $err . "</li>" . "\n";
    }
    echo '</ul></div>' . "\n";
}
?>

<?php echo form_open('my/useredit/'); ?>

<table class="inp">
<tr>
<th width="200px">メールアドレス :</th>
<td>
<input type="text" name="email" value="<?php echo set_value('email', isset($email) ? $email : ''); ?>" size="40" />
<?php echo form_error('email'); ?>
</td>
</tr>
<tr>
<th>パスワード :</th>
<td>
<input type="password" name="password" value="<?php echo set_value('password', isset($password) ? $password : ''); ?>" size="40" />
<?php echo form_error('password'); ?>
</td>
</tr>
<tr>
<th>氏名 :</th>
<td>
<input type="text" name="name" value="<?php echo set_value('name', isset($name) ? $name : ''); ?>" size="40" />
<?php echo form_error('name'); ?>
</td>
</tr>
<tr>
<th>氏名(かな) :</th>
<td>
<input type="text" name="name_kana" value="<?php echo set_value('name_kana', isset($name_kana) ? $name_kana : ''); ?>" size="40" />
<?php echo form_error('name_kana'); ?>
</td>
</tr>
<tr>
<th>郵便番号 :</th>
<td>
<input type="text" name="postcode" value="<?php echo set_value('postcode', isset($postcode) ? $postcode : ''); ?>" size="10" />
<?php echo form_error('postcode'); ?>
</td>
</tr>
<tr>
<th>都道府県 :</th>
<td>
<?php
$prefecture_options = array(
    '北海道' => '北海道',
    '青森県' => '青森県', '岩手県' => '岩手県', '宮城県' => '宮城県', '秋田県' => '秋田県',
    '山形県' => '山形県', '福島県' => '福島県', '茨城県' => '茨城県', '栃木県' => '栃木県',
    '群馬県' => '群馬県', '埼玉県' => '埼玉県', '千葉県' => '千葉県', '東京都' => '東京都',
    '神奈川県' => '神奈川県', '新潟県' => '新潟県', '富山県' => '富山県', '石川県' => '石川県',
    '福井県' => '福井県', '山梨県' => '山梨県', '長野県' => '長野県', '岐阜県' => '岐阜県',
    '静岡県' => '静岡県', '愛知県' => '愛知県', '三重県' => '三重県', '滋賀県' => '滋賀県',
    '京都府' => '京都府', '大阪府' => '大阪府', '兵庫県' => '兵庫県', '奈良県' => '奈良県',
    '和歌山県' => '和歌山県', '鳥取県' => '鳥取県', '島根県' => '島根県', '岡山県' => '岡山県',
    '広島県' => '広島県', '山口県' => '山口県', '徳島県' => '徳島県', '香川県' => '香川県',
    '愛媛県' => '愛媛県', '高知県' => '高知県', '福岡県' => '福岡県', '佐賀県' => '佐賀県',
    '長崎県' => '長崎県', '熊本県' => '熊本県', '大分県' => '大分県', '宮崎県' => '宮崎県',
    '鹿児島県' => '鹿児島県', '沖縄県', '沖縄県'
);
echo form_dropdown('prefecture', $prefecture_options, set_value('prefecture', isset($prefecture) ? $prefecture : ''));
echo form_error('prefecture');
?>
</td>
</tr>
<tr>
<th>市区町村 :</th>
<td>
<input type="text" name="city" value="<?php echo set_value('city', isset($city) ? $city : ''); ?>" size="40" />
<?php echo form_error('city'); ?>
</td>
</tr>
<tr>
<th>番地 :</th>
<td>
<input type="text" name="street" value="<?php echo set_value('street', isset($street) ? $street : ''); ?>" size="40" />
<?php echo form_error('street'); ?>
</td>
</tr>
<tr>
<th>電話番号 :</th>
<td>
<input type="text" name="phone" value="<?php echo set_value('phone', isset($phone) ? $phone : ''); ?>" size="20" />
<?php echo form_error('phone'); ?>
</td>
</tr>
</table>

<input type="submit" name="submit" value="確認画面に進む" />
</form>

<?php
include(dirname(__FILE__) . '/../footer.php');
?>
